searchData={"items":[{"type":"module","title":"BambooHR","doc":"Documentation for `BambooHR`.","ref":"BambooHR.html"},{"type":"module","title":"BambooHR.Client","doc":"Client for interacting with the BambooHR API.","ref":"BambooHR.Client.html"},{"type":"module","title":"Configuration - BambooHR.Client","doc":"To use this client, you'll need information from BambooHR:\n- Your company's subdomain\n- An API key","ref":"BambooHR.Client.html#module-configuration"},{"type":"module","title":"Usage - BambooHR.Client","doc":"config = BambooHR.Client.new(\"your_company\", \"your_api_key\")\n    {:ok, company_info} = BambooHR.Client.get_company_information(config)","ref":"BambooHR.Client.html#module-usage"},{"type":"function","title":"BambooHR.Client.add_employee/2","doc":"Adds a new employee.","ref":"BambooHR.Client.html#add_employee/2"},{"type":"function","title":"Parameters - BambooHR.Client.add_employee/2","doc":"* `config` - Client configuration\n  * `employee_data` - Map containing the employee information (firstName and lastName are required)","ref":"BambooHR.Client.html#add_employee/2-parameters"},{"type":"function","title":"Examples - BambooHR.Client.add_employee/2","doc":"iex> employee_data = %{\"firstName\" => \"Jane\", \"lastName\" => \"Smith\"}\n    iex> BambooHR.Client.add_employee(config, employee_data)\n    {:ok, %{\"id\" => 124}}","ref":"BambooHR.Client.html#add_employee/2-examples"},{"type":"function","title":"BambooHR.Client.clock_in_employee/3","doc":"Records a clock-in event for an employee.","ref":"BambooHR.Client.html#clock_in_employee/3"},{"type":"function","title":"Parameters - BambooHR.Client.clock_in_employee/3","doc":"* `config` - Client configuration\n  * `employee_id` - The ID of the employee to clock in\n  * `clock_data` - Map containing clock-in details (date, start time, timezone, etc.)","ref":"BambooHR.Client.html#clock_in_employee/3-parameters"},{"type":"function","title":"Examples - BambooHR.Client.clock_in_employee/3","doc":"iex> clock_data = %{\n    ...>   \"date\" => \"2024-01-15\",\n    ...>   \"start\" => \"09:00\",\n    ...>   \"timezone\" => \"America/New_York\"\n    ...> }\n    iex> BambooHR.Client.clock_in_employee(config, 123, clock_data)\n    {:ok, %{\"message\" => \"Successfully clocked in\"}}","ref":"BambooHR.Client.html#clock_in_employee/3-examples"},{"type":"function","title":"BambooHR.Client.clock_out_employee/3","doc":"Records a clock-out event for an employee.","ref":"BambooHR.Client.html#clock_out_employee/3"},{"type":"function","title":"Parameters - BambooHR.Client.clock_out_employee/3","doc":"* `config` - Client configuration\n  * `employee_id` - The ID of the employee to clock out\n  * `clock_data` - Map containing clock-out details (date, end time, timezone)","ref":"BambooHR.Client.html#clock_out_employee/3-parameters"},{"type":"function","title":"Examples - BambooHR.Client.clock_out_employee/3","doc":"iex> clock_data = %{\n    ...>   \"date\" => \"2024-01-15\",\n    ...>   \"end\" => \"17:00\",\n    ...>   \"timezone\" => \"America/New_York\"\n    ...> }\n    iex> BambooHR.Client.clock_out_employee(config, 123, clock_data)\n    {:ok, %{\"message\" => \"Successfully clocked out\"}}","ref":"BambooHR.Client.html#clock_out_employee/3-examples"},{"type":"type","title":"BambooHR.Client.config/0","doc":"","ref":"BambooHR.Client.html#t:config/0"},{"type":"function","title":"BambooHR.Client.get_company_eins/1","doc":"Retrieves company EINs (Employer Identification Numbers).\n\nReturns a list of EINs associated with the company.","ref":"BambooHR.Client.html#get_company_eins/1"},{"type":"function","title":"Examples - BambooHR.Client.get_company_eins/1","doc":"iex> BambooHR.Client.get_company_eins(config)\n    {:ok, %{\n      \"eins\" => [\n        %{\"ein\" => \"12-3456789\", \"name\" => \"Acme Corp\"},\n        %{\"ein\" => \"98-7654321\", \"name\" => \"Acme Subsidiary\"}\n      ]\n    }}","ref":"BambooHR.Client.html#get_company_eins/1-examples"},{"type":"function","title":"BambooHR.Client.get_company_information/1","doc":"Retrieves company information.\n\nReturns basic company details including name, address, and employee count.","ref":"BambooHR.Client.html#get_company_information/1"},{"type":"function","title":"Examples - BambooHR.Client.get_company_information/1","doc":"iex> BambooHR.Client.get_company_information(config)\n    {:ok, %{\n      \"name\" => \"Acme Corp\",\n      \"employeeCount\" => 100,\n      \"city\" => \"San Francisco\"\n    }}","ref":"BambooHR.Client.html#get_company_information/1-examples"},{"type":"function","title":"BambooHR.Client.get_employee/3","doc":"Retrieves information about a specific employee.","ref":"BambooHR.Client.html#get_employee/3"},{"type":"function","title":"Parameters - BambooHR.Client.get_employee/3","doc":"* `config` - Client configuration\n  * `employee_id` - The ID of the employee to retrieve\n  * `fields` - List of field names to retrieve (e.g., [\"firstName\", \"lastName\", \"jobTitle\"])","ref":"BambooHR.Client.html#get_employee/3-parameters"},{"type":"function","title":"Examples - BambooHR.Client.get_employee/3","doc":"iex> BambooHR.Client.get_employee(config, 123, [\"firstName\", \"lastName\", \"jobTitle\"])\n    {:ok, %{\n      \"firstName\" => \"John\",\n      \"lastName\" => \"Doe\",\n      \"jobTitle\" => \"Software Engineer\"\n    }}","ref":"BambooHR.Client.html#get_employee/3-examples"},{"type":"function","title":"BambooHR.Client.get_employee_directory/1","doc":"Retrieves the company's employee directory.\n\nReturns a list of all employees with basic information like name and contact details.","ref":"BambooHR.Client.html#get_employee_directory/1"},{"type":"function","title":"Examples - BambooHR.Client.get_employee_directory/1","doc":"iex> BambooHR.Client.get_employee_directory(config)\n    {:ok, %{\n      \"employees\" => [\n        %{\n          \"id\" => 123,\n          \"displayName\" => \"John Doe\",\n          \"jobTitle\" => \"Developer\",\n          \"workEmail\" => \"john@example.com\"\n        }\n      ]\n    }}","ref":"BambooHR.Client.html#get_employee_directory/1-examples"},{"type":"function","title":"BambooHR.Client.get_timesheet_entries/2","doc":"Retrieves timesheet entries within a specified date range.","ref":"BambooHR.Client.html#get_timesheet_entries/2"},{"type":"function","title":"Parameters - BambooHR.Client.get_timesheet_entries/2","doc":"* `config` - Client configuration\n  * `params` - Map containing query parameters (start, end dates, and optional employee IDs)","ref":"BambooHR.Client.html#get_timesheet_entries/2-parameters"},{"type":"function","title":"Examples - BambooHR.Client.get_timesheet_entries/2","doc":"iex> params = %{\n    ...>   \"start\" => \"2024-01-01\",\n    ...>   \"end\" => \"2024-01-31\",\n    ...>   \"employeeIds\" => \"123,124\"\n    ...> }\n    iex> BambooHR.Client.get_timesheet_entries(config, params)\n    {:ok, %{\n      \"entries\" => [\n        %{\n          \"id\" => \"1\",\n          \"employeeId\" => \"123\",\n          \"date\" => \"2024-01-15\",\n          \"hours\" => 8.0\n        }\n      ]\n    }}","ref":"BambooHR.Client.html#get_timesheet_entries/2-examples"},{"type":"function","title":"BambooHR.Client.new/3","doc":"Creates a new client configuration.","ref":"BambooHR.Client.html#new/3"},{"type":"function","title":"Parameters - BambooHR.Client.new/3","doc":"* `company_domain` - Your company's subdomain\n  * `api_key` - Your API key\n  * `base_url` - Optional custom base URL for the API (defaults to BambooHR's standard API URL)","ref":"BambooHR.Client.html#new/3-parameters"},{"type":"function","title":"Examples - BambooHR.Client.new/3","doc":"iex> config = BambooHR.Client.new(\"acme\", \"api_key_123\")\n    %{\n      company_domain: \"acme\",\n      api_key: \"api_key_123\",\n      base_url: \"https://api.bamboohr.com/api/gateway.php\"\n    }\n\n    # With custom base URL\n    iex> config = BambooHR.Client.new(\"acme\", \"api_key_123\", \"https://custom-api.example.com\")\n    %{\n      company_domain: \"acme\",\n      api_key: \"api_key_123\",\n      base_url: \"https://custom-api.example.com\"\n    }","ref":"BambooHR.Client.html#new/3-examples"},{"type":"type","title":"BambooHR.Client.response/0","doc":"","ref":"BambooHR.Client.html#t:response/0"},{"type":"function","title":"BambooHR.Client.store_timesheet_clock_entries/2","doc":"Stores timesheet clock entries for employees.","ref":"BambooHR.Client.html#store_timesheet_clock_entries/2"},{"type":"function","title":"Parameters - BambooHR.Client.store_timesheet_clock_entries/2","doc":"* `config` - Client configuration\n  * `entries` - List of clock entry maps containing employee ID, date, start and end times","ref":"BambooHR.Client.html#store_timesheet_clock_entries/2-parameters"},{"type":"function","title":"Examples - BambooHR.Client.store_timesheet_clock_entries/2","doc":"iex> entries = [\n    ...>   %{\n    ...>     \"employeeId\" => \"123\",\n    ...>     \"date\" => \"2024-01-15\",\n    ...>     \"start\" => \"09:00:00\",\n    ...>     \"end\" => \"17:00:00\"\n    ...>   }\n    ...> ]\n    iex> BambooHR.Client.store_timesheet_clock_entries(config, entries)\n    {:ok, %{\"message\" => \"Entries stored successfully\"}}","ref":"BambooHR.Client.html#store_timesheet_clock_entries/2-examples"},{"type":"function","title":"BambooHR.Client.update_employee/3","doc":"Updates information for an existing employee.","ref":"BambooHR.Client.html#update_employee/3"},{"type":"function","title":"Parameters - BambooHR.Client.update_employee/3","doc":"* `config` - Client configuration\n  * `employee_id` - The ID of the employee to update\n  * `employee_data` - Map containing the updated employee information","ref":"BambooHR.Client.html#update_employee/3-parameters"},{"type":"function","title":"Examples - BambooHR.Client.update_employee/3","doc":"iex> update_data = %{\"firstName\" => \"Jane\", \"lastName\" => \"Smith-Jones\"}\n    iex> BambooHR.Client.update_employee(config, 124, update_data)\n    {:ok, %{}}","ref":"BambooHR.Client.html#update_employee/3-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}